@@ -643,7 +643,22 @@ class IBMQuantumBackend:
             # Extract counts from SamplerV2 result
             # In SamplerV2, result has data attribute with BitArray
             pub_result = result[0]
-            bit_array = pub_result.data.meas
+
+            # Get the classical register name from the circuit
+            # Try common names: 'meas', 'c', or first available
+            data = pub_result.data
+            if hasattr(data, 'meas'):
+                bit_array = data.meas
+            elif hasattr(data, 'c'):
+                bit_array = data.c
+            else:
+                # Get first available attribute (classical register)
+                attrs = [attr for attr in dir(data) if not attr.startswith('_')]
+                if attrs:
+                    bit_array = getattr(data, attrs[0])
+                else:
+                    raise QuantumBackendError("No classical register found in result")
+
             counts = bit_array.get_counts()
             int_counts = counts
 
